# -*- encoding: utf-8 -*-
"""
    flask_triangle.widgets.special
    ------------------------------

    Special widgets.

    :copyright: (c) 2013 by Morgan Delahaye-Prat.
    :license: BSD, see LICENSE for more details.
"""


from __future__ import absolute_import
from __future__ import unicode_literals

from .label import Label
from .nowidget import Nowidget

__all__ = ['Label', 'Nowidget']
